@@ -15,10 +15,10 @@ from rest_flex_fields import (
 
 class FlexFieldsSerializerMixin(object):
     """
-        A ModelSerializer that takes additional arguments for
-        "fields", "omit" and "expand" in order to
-        control which fields are displayed, and whether to replace simple
-        values with complex, nested serializations
+    A ModelSerializer that takes additional arguments for
+    "fields", "omit" and "expand" in order to
+    control which fields are displayed, and whether to replace simple
+    values with complex, nested serializations
     """
 
     expandable_fields = {}
@@ -41,9 +41,7 @@ class FlexFieldsSerializerMixin(object):
                 if len(expand) > 0
                 else self._get_permitted_expands_from_query_param(EXPAND_PARAM)
             ),
-            "fields": (
-                fields if len(fields) > 0 else self._get_query_param_value(FIELDS_PARAM)
-            ),
+            "fields": (fields if len(fields) > 0 else self._get_query_param_value(FIELDS_PARAM)),
             "omit": omit if len(omit) > 0 else self._get_query_param_value(OMIT_PARAM),
         }
 
@@ -57,9 +55,7 @@ class FlexFieldsSerializerMixin(object):
         sparse_fields, next_sparse_fields = split_levels(self._flex_options["fields"])
         omit_fields, next_omit_fields = split_levels(self._flex_options["omit"])
 
-        to_remove = self._get_fields_names_to_remove(
-            omit_fields, sparse_fields, next_omit_fields
-        )
+        to_remove = self._get_fields_names_to_remove(omit_fields, sparse_fields, next_omit_fields)
 
         for field_name in to_remove:
             self.fields.pop(field_name)
@@ -77,9 +73,7 @@ class FlexFieldsSerializerMixin(object):
 
         self._flex_fields_applied = True
 
-    def _make_expanded_field_serializer(
-        self, name, nested_expand, nested_fields, nested_omit
-    ):
+    def _make_expanded_field_serializer(self, name, nested_expand, nested_fields, nested_omit):
         """
         Returns an instance of the dynamically created nested serializer.
         """
@@ -93,13 +87,12 @@ class FlexFieldsSerializerMixin(object):
             settings = {}
 
         if type(serializer_class) == str:
-            serializer_class = self._get_serializer_class_from_lazy_string(
-                serializer_class
-            )
+            serializer_class = self._get_serializer_class_from_lazy_string(serializer_class)
 
-        settings["context"] = self.context
+        if issubclass(serializer_class, serializers.Serializer):
+            settings["context"] = self.context
 
-        if issubclass(serializer_class, FlexFieldsSerializerMixin): 
+        if issubclass(serializer_class, FlexFieldsSerializerMixin):
             settings["parent"] = self
 
             if name in nested_expand:
@@ -111,8 +104,7 @@ class FlexFieldsSerializerMixin(object):
             if name in nested_omit:
                 settings[OMIT_PARAM] = nested_omit[name]
 
-
-        return serializer_class(**settings)            
+        return serializer_class(**settings)
 
     def _get_serializer_class_from_lazy_string(self, full_lazy_path: str):
         path_parts = full_lazy_path.split(".")
@@ -138,8 +130,7 @@ class FlexFieldsSerializerMixin(object):
         except ImportError:
             return (
                 None,
-                "No module found at path: %s when trying to import %s"
-                % (path, class_name),
+                "No module found at path: %s when trying to import %s" % (path, class_name),
             )
 
         try:
@@ -148,14 +139,11 @@ class FlexFieldsSerializerMixin(object):
             return None, "No class %s class found in module %s" % (path, class_name)
 
     def _get_fields_names_to_remove(
-        self,
-        omit_fields: List[str],
-        sparse_fields: List[str],
-        next_level_omits: List[str],
+        self, omit_fields: List[str], sparse_fields: List[str], next_level_omits: List[str]
     ) -> List[str]:
         """
-            Remove fields that are found in omit list, and if sparse names
-            are passed, remove any fields not found in that list.
+        Remove fields that are found in omit list, and if sparse names
+        are passed, remove any fields not found in that list.
         """
         sparse = len(sparse_fields) > 0
         to_remove = []
@@ -181,12 +169,12 @@ class FlexFieldsSerializerMixin(object):
         next_level_omits: List[str],
     ) -> bool:
         """
-            Next level omits take form of:
-            {
-                'this_level_field': [field_to_omit_at_next_level]
-            }
-            We don't want to prematurely omit a field, eg "omit=house.rooms.kitchen"
-            should not omit the entire house or all the rooms, just the kitchen.
+        Next level omits take form of:
+        {
+            'this_level_field': [field_to_omit_at_next_level]
+        }
+        We don't want to prematurely omit a field, eg "omit=house.rooms.kitchen"
+        should not omit the entire house or all the rooms, just the kitchen.
         """
         if field_name in omit_fields and field_name not in next_level_omits:
             return False
@@ -215,9 +203,7 @@ class FlexFieldsSerializerMixin(object):
             if name not in self._expandable_fields:
                 continue
 
-            if not self._should_field_exist(
-                name, omit_fields, sparse_fields, next_level_omits
-            ):
+            if not self._should_field_exist(name, omit_fields, sparse_fields, next_level_omits):
                 continue
 
             accum.append(name)
@@ -226,9 +212,9 @@ class FlexFieldsSerializerMixin(object):
 
     @property
     def _expandable_fields(self) -> dict:
-        """ It's more consistent with DRF to declare the expandable fields
-            on the Meta class, however we need to support both places
-            for legacy reasons. """
+        """It's more consistent with DRF to declare the expandable fields
+        on the Meta class, however we need to support both places
+        for legacy reasons."""
         if hasattr(self, "Meta") and hasattr(self.Meta, "expandable_fields"):
             return self.Meta.expandable_fields
 
@@ -236,7 +222,7 @@ class FlexFieldsSerializerMixin(object):
 
     def _get_query_param_value(self, field: str) -> List[str]:
         """
-            Only allowed to examine query params if it's the root serializer.
+        Only allowed to examine query params if it's the root serializer.
         """
         if self.parent:
             return []
@@ -256,9 +242,9 @@ class FlexFieldsSerializerMixin(object):
 
     def _get_permitted_expands_from_query_param(self, expand_param: str) -> List[str]:
         """
-            If a list of permitted_expands has been passed to context,
-            make sure that the "expand" fields from the query params
-            comply.
+        If a list of permitted_expands has been passed to context,
+        make sure that the "expand" fields from the query params
+        comply.
         """
         expand = self._get_query_param_value(expand_param)
 
